%This is a simulation initialisation file with all the parameters needed for running a
%shadow measurment simulation
%To run the simulation use:
%s0010_shadow2('r0006_4tx2GHz','new')
%shadow needs the full path name to this file due to the use of the run command in MATLAB
%This runs with shadowV1.5
%====================================================================================
% Simulation paprmeters
%=======================
snum = 's0010_';						%ID number for the script (This is added to the start of
%											 the filenames of all graphs generated by the script)
rnum = 'r0006_';						%Simulation result file ID, It gives a reference
%											back to this file. It is also added to the start of
%											graph filenames
AniFlag = 1;							%Animate the X,Y positions given or
%											Have simultaneous Tx with the given X,Y locations

filedirectory = 'results\tx4';		%Directory to save the QOS, capacity, 
%videos, ini file, etc
directory = 'temp';					%Tempory directory to save the calculated frames
inifile = 'intini.mat';				%initialisation file, and stores the capacity and
%											 quality of service calculations
gridscale = 1.5;						%Scaling of the number of rays and the grid sizes
pathlossexp = 2.6;						%Pathloss exponent
frequency = 2.4e9;					%Frequency of signals
BW = 20e6;								%BW of receiver in Hz
NF = 10;									%Noise Figure of receiver in dB
T = 300; 								%Antenna temperature
TxPowdB1 = 20;							%Transmitter power in dBm of the mobile transmitter
TxPowdB2 = 14;							%Transmitter power in dBm Fixed Tranmitter for each transmitter
Brange = [11 61 31 45.5];			%Building range, boundaries to use when calculating 
%											 system capacity (metres)
Brange2 = [1 51 1 15.5];			%If the Spec Eff is really low Brange and Brange2 could be wrong
X = [-8:0.4:70];								%Trajectory of the interferer
Y = [ones(size(X))*10.5];
%X = [42.1914   30.5038   20.0252    5.4156];
%Y = [7.8142   13.1694    5.8470   12.8415];
bitshz = [1:10];						%Allowable modulation schemes to use in bits/hz
diff_coherent = 0;					%0 = Coherent, 1 = Differential (not supported yet) 
Tolerance = 4;						%Tolerance abover minimum allowable SNR for each
%											 modulation scheme (dB)
xm =  [53.1198 39.0323 28.8940 16.5];
ym =  [36.7193 42.9825 36.6667 42.6316];
tx1 = xm+i*ym;							%Position of the fixed transmitters
%tx1 = [24.6500+10.9150*i]+10+30*i; %Position of Txs in experiment
%tx1 = [17.4500+10.9150*i  37.8500+10.9150*i]+10+30*i; %Experiment position
Fstr = sprintf('_%iGHz',round(frequency/1e9));
fileprefix1 = [snum rnum 'sig1' Fstr]; 	%Signal power for the mobile user
fileprefix2 = [snum rnum 'sig2' Fstr];  	%Signal power for the fixed stations
fileprefix3 = [snum rnum 'SNR1' Fstr]; 	%SNR of the mobile interfering user
fileprefix4 = [snum rnum 'SNR2' Fstr]; 	%SNR of the fixed user
%Fileprefix 5 and 6 not used if AniFlag = 0
fileprefix5 = [snum rnum 'AvSpecEff']; 	%Average Spectral Efficiency
fileprefix6 = [snum rnum 'QOS'];			%Quality of Service
coloraxis = [-120 -40];					%Colour axis to used for the signal power plots
SNRaxis = [-10 50];						%Range of SNRs to show
fontsize = 22;								%Font size of the writting that shows the QOS 
%												 and Capacity
markerwidth = 3;							%Width of the marker lines, used for indicating
%												the position of the transmitters
markersize = 15;							%Size of the marker for tx positions
horzsize = 640;							%Size of the plots to generate in pixels
vertsize = 480;
aspect = vertsize/horzsize*(1/0.87); %Aspect ratio to used when calculating the boundaries
% of the simulation. The (1/0.87) is a fudge factor due to the colour bar using some of the 
% plot see plotresult
minx = -10;									%Boundaries for the simulation
miny = -10;
maxx = 75;
maxy = (maxx-minx)*aspect+miny;
textx = 56.5;							%X location of the QOS and Capacity text on the SNR plots
textybHz = -3;							%Y location of the average bits/Hz
textyqos = -7;							%Y location of the Quality of Service Calculation
N = 1; 									%Number of simulations to use to sim diffraction, 
%											 N=1 is the fastest, 5>=N>=1
diff_dist = 0.4; 						%distance between diffraction simultatons in metres
figbackrate = 50;	%The simulation plots are saved in the tempory directory ('directory' variable)
% One in every figbackrate simulations will be saved to the filedirectory as well.
% This is for keeping a long term record of the simulation.
modeltype = 2;							%Model type, see genmodel used for raytracing
dispmodeltype = 2; 					%Model to used for putting on the plots
%================================================================================
