%s0009_plotQOS_Cap. This script plots the capacity (Average Spectral Efficiency) and 
%Quality of service (Percent area of the building with SNR < 1 bits/Hz) for multiple 
%simulations. S0009_plotQOS_Cap is currently setup to compare a two building simulation 
%with one, two and four fixed transmitters. A moving interferer moves through the second
%building causing interference. These plots show the effect on the fixed multiple transmitter
%building.

files = {'results\tx1\intini.mat','results\tx2\intini.mat','results\tx4\intini.mat','results\tx8\intini.mat'};

%If the simulation data files are missing, indicate which simulation need to be run
%to regenerate the simulation files. These are initialisation files for s0010_shadow2
resim = {'r0011_1tx2GHz','r0010_2tx2GHz','r0006_4tx2GHz','r0012_8tx2GHz'};
colourlist = 'brgkcmybrgkcmy';	%List of colours for the plot lines
legendtext = {'1 transmitter','2 transmitters','4 transmitters','8 transmitters'};
linewidth = [2 3 4 6];	%Width of the plot lines
QOS_y_axis = [-0.3 45];	%Y axis for for QOS (area) graph. This is here to allow triming
%of the plot. It was found that setting the lower limit just below 0 allowed thick
%plot lines to show up the correct thickness.

contin = 1;		%Flag to indicate if all simulation files are present
%Check that the simulation files exist
for k = 1:length(files)
	if ~exist(files{k},'file')
   	disp(['Missing : ' files{k}]);
   	disp(['run: s0010_shadow2(''' resim{k} ''',''new'')']);
   	contin = 0;
	end
end
if contin == 0
   error('Not all simulation files present, aborting plotting of data')
end

%Initalise the cell arrays for holding th simulation results
Capacity1 = cell(length(files));
QOS1 = cell(length(files));
X1 = cell(length(files));

for k = 1:length(files)   
	load(files{k})
	Capacity1{k} = Capacity;
	QOS1{k} = QOS;
	X1{k} = X;
end


figure(1)
clf
h = zeros(1,length(files));	%Keep the handles to the plot lines for making a legend

for k = 1:length(files)
   x = X1{k};
   Q = QOS1{k};
   h(k) = plot(x(1:length(Q)),Q,colourlist(k));
   hold on
end
hold off
legend(h,legendtext,2);
xlabel('Distance travelled by interfering mobile user (m)')
ylabel('Percentage Area < 1 bits/Hz')
setplotstyle
for k = 1:length(files)
   set(h(k),'linewidth',linewidth(k));
end
legend
ylim(QOS_y_axis);
savefig('s0009_QOS_comparison');
figure(2)
clf
h = zeros(1,length(files));	%Keep the handles to the plot lines for making a legend
for k = 1:length(files)
   x = X1{k};
   C = Capacity1{k};
   h(k) = plot(x(1:length(C)),C,colourlist(k));
   hold on
end
hold off
legend(h,legendtext,3);
xlabel('Distance travelled by interfering mobile user (m)')
ylabel('Average Spectal Efficiency')
setplotstyle
for k = 1:length(files)
   set(h(k),'linewidth',linewidth(k));
end
legend
savefig('s0009_AvSpecEff_Comparsion')

