function s0010_shadow(simfile,arg)
%S0010_SHADOW raytraces to find shadowing and interference between radio transmitters
% s0010_shadow(simnumber,arg)
% simfile = Runs a predefined simulation decribed in the file given, 
% arg : 'cont' continue previous unfinished simulation (default)
%       'new' delete initialisation file and start new simulation again
%		  'select' plot the object model, and allow selection of X, Y locations with
%		  the mouse.

%Copyright (1) Eric Lawrey August 2000,
% Version 2.4
% 2/8/00 version 2.2
% Improved the 'select' input so that the axis setting on the plots match the 
% simulation file given, and it also prints out X and Y better
% 
% 3/8/00 version 2.3
% -Shadow was not copying over the fixed transmitters signal power plot to the
% results directory. I changed it so that it gets saved directly into th results
% directory
% -Added semicolons to the X,Y data in select mode
% 
% 3/8/00 version 2.4
% s0010_shadow now creates the filedirectoy and temp directory 'directory' is they
% don't exist yet
%
% 11/11/00 version 2.5
% Fixed up a bug caused by mkdir. It was not creating the results and temp directories
% correctly as the directory name was nested. 
% Mkdir has a bug in it such that if you ask it to make nested directories, such as
% mkdir('temp\test'), where temp and test directories don't exist, mkdir still returns
% that it was successful even though no directories were made.
% Added function mkdir2 to work around this problem.
if nargin < 2
   arg = 'cont';
end
if nargin <1
   disp('No simulation file given, running ''defaultsim'' ');
   simfile = 'defaultsim';
end
snum = 's0010_';
run(simfile) 

if ~exist(filedirectory,'dir')
 	mkdir2(filedirectory)
   
end
if ~exist(directory,'dir')
	mkdir2(directory)
end

range = [minx maxx miny maxy];
NoisePow = 1.38e-23*T*BW*(10.^(NF/10))*1000;	%Noise power in mW
TxPow1 = 10.^(TxPowdB1/10);
TxPow2 = 10.^(TxPowdB2/10);
objs = genmodel(modeltype); %Get the model for the ECE building at JCU   
objs2 = genmodel(dispmodeltype);			%Model to plot using. This can be different to the object model
% used for the ray tracing.

switch lower(arg)
case 'new'
   if exist([filedirectory filesep inifile],'file')
      delete([filedirectory filesep inifile])
   end
case 'select'
   %This is useful for getting X,Y values for positioning the transmitters
   plotmodelobj(objs);
   axis(range)
   disp('Click on locations for the transmitters, hit enter to stop')
   [xm,ym] = ginput;
   hold on
   plot(xm,ym,'rx','markersize',24,'linewidth',3)
   hold off
   disp(['X = ['sprintf('%0.2f ',xm) '];'])
   disp(['Y = ['sprintf('%0.2f ',ym) '];'])
   return
end
txloc = X+i*Y;

if AniFlag == 1
   %===============================================================================
   %Animate the mobile user using given X, Y locations
   
   if ~exist([filedirectory filesep inifile],'file')
      disp('New simulation');
      
      figure(1)
      for k = 1:length(tx1)
         [x,y,z2] = rtdiffract(tx1(k),diff_dist,'default',modeltype,range,horzsize,vertsize,coloraxis,N,...
            gridscale,frequency,pathlossexp);
         zlin1 = 10.^((z2+TxPowdB2)/10);
         if k>1
            zt = zt+zlin1;
         else
            zt = zlin1;
         end
         
      end
      zlin2 = zt;
      z2 = 10*log10(zt);
      %filedirectory 
      %filesep 
      %fileprefix2
      filename = [filedirectory filesep fileprefix2];
      plotresult(x,y,10*log10(zlin2),objs2,filename,horzsize,vertsize,coloraxis,1);
      hold on
      plot(tx1,'rx','markersize',markersize,'linewidth',markerwidth)
      hold off
      savefig(filename,'jpg');
      K = 1;
      Capacity = [];
      QOS = [];
   else
      load([filedirectory filesep inifile]);
      disp('continuing previous simultion');
      K=K+1;	%K has the index of the last completed simulation, start the next one
   end
   
   for k = K:length(X)
      
      tx2 = txloc(k);
      figure(1)
      [x,y,z] = rtdiffract(tx2,diff_dist,'default',modeltype,range,horzsize,vertsize,coloraxis,N,...
         gridscale,frequency,pathlossexp);
      zlin1 = 10.^((z+TxPowdB1)/10);
      
      SNR1 = 10*log10(zlin1./(zlin2+NoisePow));		%SNR for the mobile unit
      SNR2 = 10*log10(zlin2./(zlin1+NoisePow));		%Signal to noise ratio within the second building
      %zt = 10*log10((zlin1+zlin2)/2);
      s = [int2str(k)];
      z = '000';
      s2 = [z(1:(length(z)-length(s))) s];
      
      
      indx = find((x>Brange(1))&(x<Brange(2)));
      indy = find((y>Brange(3))&(y<Brange(4)));
      SNRfixed = SNR2(indy,indx);	%Find the SNR in the building with the fixed transmitter
      ModSpecEff1 = modscheme(SNRfixed,bitshz,diff_coherent,Tolerance);
      M1 = ModSpecEff1(find(~isnan(ModSpecEff1)));
      
      Area1 = length(find(M1<1))/length(M1(:))*100;
      SMOD = sprintf('%3.2fb/Hz',mean(mean(M1)));
      %   [num2str(mean(mean(M1))) 'b/Hz'];
      SQOS = sprintf('%3.2f%%',Area1);
      
      Capacity = [Capacity mean(mean(M1))];
      QOS = [QOS Area1];
      
      figure(1)
      filename = [directory filesep fileprefix1 s2];
      
      plotresult(x,y,10*log10(zlin1),objs2,filename,horzsize,vertsize,coloraxis,1);
      hold on
      plot(tx2,'rx','markersize',markersize,'linewidth',markerwidth)
      hold off
      savefig(filename,'jpg');
      if rem(k,figbackrate) == 1
         savefig([filedirectory filesep fileprefix1 s2],'jpg');
      end
      
      %SNR for mobile unit, tx2 is mobile unit
      figure(2)
      filename = [directory filesep fileprefix3 s2];  
      plotresult(x,y,SNR1,objs2,filename,horzsize,vertsize,SNRaxis,1)
      colormap(jet)
      hold on
      plot([tx1],'wx','markersize',markersize,'linewidth',markerwidth)
      plot([tx2],'kx','markersize',markersize,'linewidth',markerwidth)
      hold off   
      savefig(filename,'jpg');
      %Save a backup of the figures, but don't keep every one
      if rem(k,figbackrate) == 1
         savefig([filedirectory filesep fileprefix3 s2],'jpg');
      end
      
      
      figure(3)
      %SNR for the fixed stations
      filename = [directory filesep fileprefix4 s2];
      
      plotresult(x,y,SNR2,objs2,filename,horzsize,vertsize,SNRaxis,1)
      colormap(jet);
      hold on
      plot([tx1],'kx','markersize',markersize,'linewidth',markerwidth)
      plot([tx2],'wx','markersize',markersize,'linewidth',markerwidth)
      hold off
      text(textx,textybHz,SMOD,'fontsize',fontsize,'fontweight','bold','color',[1 1 1]);
      text(textx,textyqos,SQOS,'fontsize',fontsize,'fontweight','bold','color',[1 1 1]);
      savefig(filename,'jpg');
      if rem(k,figbackrate) == 1
         savefig([filedirectory filesep fileprefix4 s2],'jpg');
      end
      
      figure(4)
      clf
      plot(X(1:length(Capacity)),Capacity);
      title('Average Spectral Efficiency');
      xlabel('Movement of interferer (m)');
      ylabel('Spectral Efficiency (bits/Hz)');
      setplotstyle
      savefig([filedirectory filesep fileprefix5]);
      
      figure(5)
      clf
      plot(X(1:length(QOS)),QOS);
      title('Quality of Service');
      xlabel('Movement of interferer (m)');
      ylabel('% building area < 1 bit/Hz'); 
      setplotstyle
      savefig([filedirectory filesep fileprefix6]);
      
      K = k;
      save([filedirectory filesep inifile],'K','x','y','z2','zlin2','X','Y','Capacity','QOS',...
         'BW','NF','T','TxPowdB1','TxPowdB2')
      disp('==========================');
      
   end
   disp('simulation complete');
else
   
   figure(1)
   colormap(gray);
   %Calculate station 1
   for k = 1:length(tx1)
      [x,y,z2] = rtdiffract(tx1(k),diff_dist,'default',modeltype,range,horzsize,vertsize,coloraxis,N,...
         gridscale, frequency, pathlossexp);
      zlin1 = 10.^((z2+TxPowdB2)/10);
      if k>1
         zt = zt+zlin1;
      else
         zt = zlin1;
      end
   end
   zlin1 = zt;
   z1 = 10*log10(zt);
   filename = [filedirectory filesep fileprefix1];
   plotresult(x,y,10*log10(zlin1),objs2,filename,horzsize,vertsize,coloraxis,1);
   hold on
   plot(tx1,'rx','markersize',markersize,'linewidth',markerwidth)
   hold off
   savefig(filename,'jpg');
   
   figure(1)
   %Calculate station 2
   for k = 1:length(txloc)
      [x,y,z2] = rtdiffract(txloc(k),diff_dist,'default',modeltype,range,horzsize,vertsize,coloraxis,N,...
         gridscale,frequency,pathlossexp);
      zlin2 = 10.^((z2+TxPowdB1)/10);
      if k>1
         zt = zt+zlin2;
      else
         zt = zlin2;
      end   
   end
   zlin2 = zt;
   z2 = 10*log10(zt);
   filename = [filedirectory filesep fileprefix2];
   plotresult(x,y,10*log10(zlin2),objs2,filename,horzsize,vertsize,coloraxis,1);
   hold on
   plot(txloc,'rx','markersize',markersize,'linewidth',markerwidth)
   hold off
   savefig(filename,'jpg');
   
   SNR1 = 10*log10(zlin2./(zlin1+NoisePow));		%SNR for the mobile unit
   SNR2 = 10*log10(zlin1./(zlin2+NoisePow));		%Signal to noise ratio within the second building
   %========================================
   indx = find((x>Brange2(1))&(x<Brange2(2)));
   indy = find((y>Brange2(3))&(y<Brange2(4)));
   SNRfixed = SNR1(indy,indx);	%Find the SNR in the building with the fixed transmitter
   ModSpecEff1 = modscheme(SNRfixed,bitshz,diff_coherent,Tolerance);
   M1 = ModSpecEff1(find(~isnan(ModSpecEff1)));
   
   Area1 = length(find(M1<1))/length(M1(:))*100;
   SMOD = sprintf('%3.2fb/Hz',mean(mean(M1)));
   %   [num2str(mean(mean(M1))) 'b/Hz'];
   SQOS = sprintf('%3.2f%%',Area1);
   %========================================
   indx = find((x>Brange(1))&(x<Brange(2)));
   indy = find((y>Brange(3))&(y<Brange(4)));
   SNRfixed = SNR2(indy,indx);	%Find the SNR in the building with the fixed transmitter
   ModSpecEff1 = modscheme(SNRfixed,bitshz,diff_coherent,Tolerance);
   M1 = ModSpecEff1(find(~isnan(ModSpecEff1)));
   
   Area1 = length(find(M1<1))/length(M1(:))*100;
   SMOD2 = sprintf('%3.2fb/Hz',mean(mean(M1)));
   %   [num2str(mean(mean(M1))) 'b/Hz'];
   SQOS2 = sprintf('%3.2f%%',Area1);
   %========================================
   %SNR for mobile unit, tx2 is mobile unit
   
   
   
   
   %SNR for mobile unit, tx2 is mobile unit
   figure(1)
   filename = [filedirectory filesep fileprefix3];
   plotresult(x,y,SNR1,objs2,filename,horzsize,vertsize,SNRaxis,1)
   colormap(jet)
   hold on
   plot([tx1],'wx','markersize',markersize,'linewidth',markerwidth)
   plot(txloc,'kx','markersize',markersize,'linewidth',markerwidth)
   hold off   
   text(textx,textybHz,SMOD,'fontsize',fontsize,'fontweight','bold','color',[1 1 1]);
   text(textx,textyqos,SQOS,'fontsize',fontsize,'fontweight','bold','color',[1 1 1]);
   savefig(filename,'jpg');
   
   
   figure(2)
   %SNR for the fixed stations
   filename = [filedirectory filesep fileprefix4];
   plotresult(x,y,SNR2,objs2,filename,horzsize,vertsize,SNRaxis,1)
   colormap(jet);
   hold on
   plot([tx1],'kx','markersize',markersize,'linewidth',markerwidth)
   plot(txloc,'wx','markersize',markersize,'linewidth',markerwidth)
   hold off
   text(textx,textybHz,SMOD2,'fontsize',fontsize,'fontweight','bold','color',[1 1 1]);
   text(textx,textyqos,SQOS2,'fontsize',fontsize,'fontweight','bold','color',[1 1 1]);
   savefig(filename,'jpg');
end

%===========================================================
function mkdir2(directory)
%This function works around the bug in mkdir.
%Mkdir has a bug in it such that if you ask it to make nested directories, such as
%mkdir('temp\test'), where temp and test directories don't exist, mkdir still returns
%that it was successful even though no directories were made.
[t,r] = strtok(directory,filesep);
total = t;
outstatus = 1;
while ~isempty(t)
   [status, msg] = mkdir(total);
   if status == 0
      outstatus = 0;
      error(['Failed to create directory for results : ' directory ', ' msg]);
   end
   [t,r] = strtok(r,filesep);
   total = [total filesep t];
end
disp(['Created directory for results : ' directory]);

   